pub fn look_to_quat(dir: Vec3, up: Vec3) -> QuatExpand description
Returns a Quat view rotation from direction and up.
Transforms left-handed world space points into left-handed Y-up view space.
Panics
Will panic if dir or up are not normalized when glam_assert is enabled.