look_at_quat

Function look_at_quat 

pub fn look_at_quat(eye: Vec3, center: Vec3, up: Vec3) -> Quat
Returns a Quat view rotation from eye, focal point, and up.

Transforms right-handed world space points into right-handed Y-up view space.

Panics

Will panic if up is not normalized when glam_assert is enabled.