frustum

Function frustum 

pub fn frustum(
    left: f64,
    right: f64,
    bottom: f64,
    top: f64,
    near: f64,
    far: f64,
) -> DMat4
Creates a perspective projection from a frustum for use with DirectX and WebGPU.

Expects a left-handed Y-up view space input. Outputs NDC with Z in [0, 1] and Y-up.

Panics

Will panic if near or far are less than or equal to zero when glam_assert is enabled.