perspective_infinite

Function perspective_infinite 

pub fn perspective_infinite(
    vertical_fov: f64,
    aspect_ratio: f64,
    near: f64,
) -> DMat4
Creates an infinite perspective projection matrix for use with Vulkan.

Like perspective, but with an infinite value for far. Points at distance near map to depth 0; as distance approaches infinity, depth approaches 1.

Expects a left-handed Y-up view space input. Outputs NDC with Z in [0, 1] and Y-down.

Panics

Will panic if near is less than or equal to zero when glam_assert is enabled.